package es.unican.docencia.informatica.cuarto.seminarioAspectos.controlAccesos;

/**
 * Class which is on charge of controlling access to confidential information
 * @author Pablo Snchez (p.sanchez@unican.es)
 * 		   http://personales.unican.es/sanchezbp	
 */
public class AccessControl {
	
	/**
	 * Unique username and password. Security is high in this toy application :-)
	 */
	static final private String _username = "Pablo";
	static final private String _password = "123";
	
	/**
	 * It returns true if the user is registered in the system, 
	 * otherwise, it returns false
	 * @param  username Nickname for the user registered in the system
	 * @return a boolean value signaling if the user is registered in the system. 
	 */
	private boolean registered (String username) {
		return _username.equals(username);
	} // registered
	
	/**
	 * Returns the password stored in the database for the corresponding username
	 * @param username Username for which we need to recover the password
	 * @return The password corresponding to the username given as parameter
	 */
	private String getPassword(String username) {
		return _password;
	} // getPassword
		
	/**
	 * Indicates if a user is authorized or not. There is a 
	 * single level of authorization 
	 * @param username The nickname of the user
	 * @param password The password entered by the user
	 * @return True is the user is authorized, otherwise false 
	 */
	public boolean isAuthorized(String username, String password) {
		
		boolean isRegistered = false;
		
		if (registered(username)) {
			if (getPassword(username).equals(password)) {
				isRegistered = true;
			} // if
		} // if
		return isRegistered;
	}  // isAuthorized
	
	/**
	 * Ask for a username and password, and returns true is the pair
	 * (username, password) is registered in the system database.  
	 * Otherwise, the user has not access to the operation and the 
	 * function returns false 
	 * @return true is the user is granted access to the operation, 
	 * 		   false otherwise
	 */
	 public boolean getAccess() {
	 
		AuthorizationView view = new AuthorizationView();
			
		String username = view.askForUsername();
        String password = view.askForPassword();
		return isAuthorized(username,password); 
	}

}
