package es.unican.docencia.informatica.cuarto.seminarioAspectos.controlAccesos;

import java.util.LinkedList;
import java.util.List;

/**
 * Data class representing a student. Some attributes are confidential 
 * and therefore are protected by the access control crosscutting concern 
 * @author Pablo Snchez (p.sanchez@unican.es)
 *		   http://personales.unican.es/sanchezbp
 */
public class Student {
	
	/**
	 * According to Spanish laws, this data is confendential and only
	 * people with the right privileges may access it  
	 */
	protected String religion;
	protected List<String> diseases = new LinkedList<String>();;  
	
	/**
	 * Reference to the access controller
	 */
	protected AccessControl authenticator = new AccessControl();

	
	/**
	 * Getter method for the religion attribute. 
	 * According to Spanish laws, this data is confendential and only
	 * people with the right privileges may access it  
	 * @return The religion of the student that receives the call
	 */
	public String getReligion() {

		String result = null; 
		
		// If we have access, we return the attribute, 
		// otherwise, we do nothing and null is returned
		if (authenticator.getAccess()) {
			result = this.religion;
		}  // if
		
		return result;
	} // getReligion 

	/**
	 * Setter method for the religion attribute
	 * @param religion The new religion value to be set
	 */
	public void setReligion(String religion) {
		this.religion = religion;
	} // setReligion

	/**
	 * Getter method for the diseases attribute, which is an unbounded list 
	 * @return The list of the student's diseases 
	 */
	public List<String> getDiseases() {

		List<String> result = null; 
		
		// If we have access, we return the attribute, otherwise,
		// we rise an exception
		if (authenticator.getAccess()) {
			result = this.diseases;
		}  // if

		return result;
	} // getDiseases

	/**
	 * 
	 * @param diseases the diseases to set
	 */
	public void addDiseases(List<String> diseases) {
		this.diseases = diseases;
	} // addDiseases
	
} // Student
