package es.unican.docencia.informatica.cuarto.seminarioAspectos.controlAccesos.aspectos;

/**
 * Class which is on charge of controlling access to confidential information
 * @author Pablo Snchez (p.sanchez@unican.es)
 * 		   http://personales.unican.es/sanchezbp	
 */
public class AccessControl {
	
	/**
	 * Unique username and password. Security is high in this toy application :-)
	 */
	static final protected String _username = "Pablo";
	static final protected String _password = "123";
	
	//**------------------------------------------------------------------------**//
	//** 						Class Public Interface						    **//
	//**------------------------------------------------------------------------**//
	
	/**
	 * Ask for a username and password, and returns true if the pair
	 * (username, password) is registered in the system database.  
	 * Otherwise, the user has not access to the operation and the 
	 * function returns false 
	 * @return true is the user is granted access to the operation, 
	 * 		   false otherwise
	 */
	public boolean getAccess() {
		
		System.out.println("Executing Non Selective"); 
		
		String result [] = getUsernameAndPassword();
		
		System.out.println("End Executing Non Selective");
		
		return isAuthorized(result[0],result[1]); 
	} // getAccess
	
	/**
	 * Ask for a username and a password, and returns true if the pair
	 * (username, password) is registered in the system database and 
	 * the user has priviliges to access to the method given as a parameter  
	 * Otherwise, the user has not access to the operation and the 
	 * function returns false 
	 * @param method 
	 * @return True is the user is granted access to the operation, 
	 * 		   otherwise false
	 */
	public boolean getSelectiveAccess(String method) {
		
		String result [] = getUsernameAndPassword();
		
        return isAuthorized(result[0],result[1]) && 
               hasPrivilege(result[0],method); 
	} // getSelectiveAccess

	//**------------------------------------------------------------------------**//
	//** 						    Helper methods 								**//
	//**------------------------------------------------------------------------**//
	
	/**
	 * It returns true if the user is registered in the system, 
	 * otherwise, it returns false
	 * @param  username Nickname for the user registered in the system
	 * @return a boolean value signaling if the user is registered in the system. 
	 */
	protected boolean registered (String username) {
		return _username.equals(username);
	} // registered

	/**
	 * Returns the password stored in the database for the corresponding username
	 * @param username Username for which we need to recover the password
	 * @return The password corresponding to the username given as parameter
	 */
	protected String getPassword(String username) {
		return _password;
	} // getPassword

	/**
	 * Indicates if a user is authorized or not. There is a 
	 * single level of authorization 
	 * @param username The nickname of the user
	 * @param password The password entered by the user
	 * @return True is the user is authorized, otherwise false 
	 */
	protected boolean isAuthorized(String username, String password) {
		
		boolean isRegistered = false;
		
		if (registered(username)) {
			if (getPassword(username).equals(password)) {
				isRegistered = true;
			} // if
		} // if
		return isRegistered;
	}  // isAuthorized
	
	/**
	 * Indicates if a user has privileges to access to a concrete method,
	 * whose name is passed as a parameter 
	 * @param username Name of the user whose privileges are going to be checked
	 * @param method Name of the method whose access privileges has to be checked
	 * @return True is the user has the privileges to access to the method, 
	 *         False otherwise
	 */
	protected boolean hasPrivilege(String username, String method) {
		// For the sake of simplicity, we simply  return true
		return true;
	} // isAuthorized
	
	/**
	 * Returns the pair username, password after reading them by console
	 * @return The pair username and password. The username is returned 
	 * 		   in the zero position, and the password is returned in the 
	 *         the next one. 
	 */
	protected String [] getUsernameAndPassword() {
		
		AuthorizationView view = new AuthorizationView();
		
		String result [] = new String[2];
		
		result[0] = view.askForUsername();
        result[1] = view.askForPassword();
 
		return result;
        
	}  // getUsernameAndPassword
	
} // AccessControl
