package es.unican.docencia.informatica.cuarto.seminarioAspectos.controlAccesos.aspectos;

import es.unican.docencia.informatica.cuarto.seminarioAspectos.controlAccesos.AccessControl;

/**
 * Aspect for injecting access control in methods that must be 
 * protected. It uses quantification. 
 * @author Pablo Snchez (p.sanchez@unican.es)
 *		   http://personales.unican.es/sanchezbp
 */
public aspect QuantifiedAccessControlAspect {
	
	/**
	 * Pointcut indicating which methods should be protected
	 */
	pointcut guardedMethods(): call(* Student.get*(..));
	
	/**
	 * Advice to be executed around the methods whose access 
	 * must be controlled
	 * @return The return value of the intercepted method if 
	 *         the user has access, otherwise null
	 */
	Object around() : guardedMethods() {
		 
		 AccessControl guard = new AccessControl();
		 
		 Object returnValue = null;
		 
		 if (guard.getAccess()) {
			 returnValue = proceed();
		 } // if
		 
		return returnValue;
 	} // around guardedMethods 

} // QuantifiedAccessControlAspect
